Content
=======

All content can be changed via the :ref:`AdminPanel`. 

.. toctree::
   :maxdepth: 2
   
   Page parts <PageParts>
   Seo configuration <SeoConfiguration>
   Technical configuration <TechnicalConfiguration>
   Preferences <Preferences>
